# PatchDataPlaneCapabilities


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**gen_ai_enabled** | **bool** |  | [optional] 

## Example

```python
from arthur_client.api_bindings.models.patch_data_plane_capabilities import PatchDataPlaneCapabilities

# TODO update the JSON string below
json = "{}"
# create an instance of PatchDataPlaneCapabilities from a JSON string
patch_data_plane_capabilities_instance = PatchDataPlaneCapabilities.from_json(json)
# print the JSON string representation of the object
print(PatchDataPlaneCapabilities.to_json())

# convert the object into a dict
patch_data_plane_capabilities_dict = patch_data_plane_capabilities_instance.to_dict()
# create an instance of PatchDataPlaneCapabilities from a dict
patch_data_plane_capabilities_from_dict = PatchDataPlaneCapabilities.from_dict(patch_data_plane_capabilities_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


